@@ -4,7 +4,6 @@ import logging
 import re
 import inject
 from mcloud.config import YamlConfig, ConfigParseError
-from mcloud.sync.utils import VolumeNotFound
 import os
 from twisted.internet import defer, reactor
 from twisted.internet.defer import inlineCallbacks
@@ -26,12 +25,19 @@ class Application(object):
         self.name = name
         self.public_urls = public_urls or []
 
+    def get_env(self):
+        if 'env' in self.config and self.config['env']:
+            env = self.config['env']
+        else:
+            env = 'dev'
+        return env
+
     @defer.inlineCallbacks
     def load(self, need_details=False):
 
         try:
             if 'source' in self.config:
-                yaml_config = YamlConfig(source=self.config['source'], app_name=self.name, path=self.config['path'])
+                yaml_config = YamlConfig(source=self.config['source'], app_name=self.name, path=self.config['path'], env=self.get_env())
             elif 'path' in self.config:
                 yaml_config = YamlConfig(file=os.path.join(self.config['path'], 'mcloud.yml'), app_name=self.name, path=self.config['path'])
             else:
@@ -39,6 +45,8 @@ class Application(object):
 
             yaml_config.load()
 
+            
+
             yield defer.gatherResults([service.inspect() for service in yaml_config.get_services().values()])
 
             if need_details:
@@ -89,6 +97,8 @@ class Application(object):
 
         return {
             'name': self.name,
+            'hosts': app_config.get_hosts(),
+            'volumes': app_config.get_volumes(),
             'fullname': '%s.%s' % (self.name, self.dns_search_suffix),
             'web_ip': web_ip,
             'web_service': web_service,
@@ -123,10 +133,14 @@ class ApplicationController(object):
         defer.returnValue(Application(config, name=name))
 
     @defer.inlineCallbacks
-    def update_source(self, name, source, skip_validation=False):
+    def update_source(self, name, source=None, skip_validation=False, env=None):
 
         app = yield self.get(name)
-        app.config.update({'source': source})
+        if source:
+            app.config.update({'source': source})
+
+        if env:
+            app.config.update({'env': env})
 
         # validate first by crating application instance
         if not skip_validation:
